==> ros-kinetic-py-trees-ros_0.5.5.orig.tar.gz: ros-kinetic-py-trees-ros-0.5.5/README.md <==
# Py Trees for ROS

## About

Behaviours, trees and utilities that extend [py_trees](https://github.com/stonier/py_trees) for use
with ROS.

Refer to the [package documentation](https://stonier.github.io/py_trees_ros/) for more information.

## Build Status

The currently supported ROS Distro is Kinetic.

| Devel | Kinetic |
|:---:|:---:|
| [![devel-Sources][devel-sources-image]][devel-sources] | [![0.5.x-Sources][0.5.x-sources-image]][0.5.x-sources] |
| [![devel-Status][devel-build-status-image]][devel-build-status] | [![kinetic-Status][kinetic-build-status-image]][kinetic-build-status] | |
| [![devel-Docs][devel-docs-image]][devel-docs] | |

[devel-sources-image]: http://img.shields.io/badge/sources-devel-blue.svg?style=plastic
[devel-sources]: https://github.com/stonier/py_trees_ros/tree/devel
[0.5.x-sources-image]: http://img.shields.io/badge/sources-0.5.x--kinetic-blue.svg?style=plastic
[0.5.x-sources]: https://github.com/stonier/py_trees_ros/tree/release/0.5-kinetic

[devel-build-status-image]: http://build.ros.org/job/Kdev__py_trees_ros__ubuntu_xenial_amd64/badge/icon?style=plastic
[devel-build-status]: http://build.ros.org/job/Kdev__py_trees_ros__ubuntu_xenial_amd64                     
[kinetic-build-status-image]: http://build.ros.org/job/Kbin_uX64__py_trees_ros__ubuntu_xenial_amd64__binary/badge/icon?style=plastic
[kinetic-build-status]: http://build.ros.org/job/Kbin_uX64__py_trees_ros__ubuntu_xenial_amd64__binary

[devel-docs-image]: https://img.shields.io/badge/docs-devel-brightgreen.svg?style=plastic
[devel-docs]: https://stonier.github.io/py_trees_ros/

## The ROS Py Trees Repositories

* [py_trees](https://github.com/stonier/py_trees)
* [py_trees_msgs](https://github.com/stonier/py_trees_msgs)
* [py_trees_ros](https://github.com/stonier/py_trees_ros)
* [rqt_py_trees](https://github.com/stonier/rqt_py_trees)

==> ros-kinetic-py-trees-ros_0.5.13.orig.tar.gz: ros-kinetic-py-trees-ros-0.5.13/README.md <==
# Py Trees for ROS

Behaviours, trees and utilities that extend py_trees for use
with ROS.

## Documentation

Refer to the sphinx docs for [py_trees](http://py-trees.readthedocs.io/en/devel/) as a primer and reference on behaviour trees & [py_trees_ros](https://stonier.github.io/py_trees_ros/) for tutorials on getting started with behaviour trees in ROS.

## The ROS Py Trees Packages

* [py_trees](https://github.com/stonier/py_trees) ([sphinx docs](http://py-trees.readthedocs.io/en/devel/))
* [py_trees_msgs](https://github.com/stonier/py_trees_msgs)
* [py_trees_ros](https://github.com/stonier/py_trees_ros) ([sphinx docs](https://stonier.github.io/py_trees_ros/))
* [rqt_py_trees](https://github.com/stonier/rqt_py_trees)

## Build Status

The currently supported ROS Distro is Kinetic.

| Devel | Kinetic |
|:---:|:---:|
| [![devel-Sources][devel-sources-image]][devel-sources] | [![0.5.x-Sources][0.5.x-sources-image]][0.5.x-sources] |
| [![devel-Status][devel-build-status-image]][devel-build-status] | [![kinetic-Status][kinetic-build-status-image]][kinetic-build-status] | |
| [![devel-Docs][devel-docs-image]][devel-docs] | |

[devel-sources-image]: http://img.shields.io/badge/sources-devel-blue.svg?style=plastic
[devel-sources]: https://github.com/stonier/py_trees_ros/tree/devel
[0.5.x-sources-image]: http://img.shields.io/badge/sources-0.5.x--kinetic-blue.svg?style=plastic
[0.5.x-sources]: https://github.com/stonier/py_trees_ros/tree/release/0.5-kinetic

[devel-build-status-image]: http://build.ros.org/job/Kdev__py_trees_ros__ubuntu_xenial_amd64/badge/icon?style=plastic
[devel-build-status]: http://build.ros.org/job/Kdev__py_trees_ros__ubuntu_xenial_amd64                     
[kinetic-build-status-image]: http://build.ros.org/job/Kbin_uX64__py_trees_ros__ubuntu_xenial_amd64__binary/badge/icon?style=plastic
[kinetic-build-status]: http://build.ros.org/job/Kbin_uX64__py_trees_ros__ubuntu_xenial_amd64__binary

[devel-docs-image]: https://img.shields.io/badge/docs-devel-brightgreen.svg?style=plastic
[devel-docs]: https://stonier.github.io/py_trees_ros/
